@@ -166,7 +166,7 @@
           # Compute GLM coefficients used for penalty weights
           glm.fit <- speedglm.wfit(y = y, X = X, intercept = TRUE, family = family, weights = weights, offset = offset,
                                    start = NULL, eigendec = FALSE, 
-                                   sparse = ifelse(class(X) %in% c("dgCMatrix"), TRUE, NULL), 
+                                   sparse = ifelse(class(X)[1] %in% c("dgCMatrix"), TRUE, NULL), 
                                    trace = FALSE)
           
           beta.weights <- glm.fit$coefficients
