@@ -1,5 +1,5 @@
-# Munich rent data
-data("rent")
+# Munich rent data from catdata package
+data("rent", package = "catdata")
 
 # The considered predictors are the same as in 
 # Gertheiss and Tutz (Ann. Appl. Stat., 2010).
